@@ -1,6 +1,6 @@
 package CGI::ContactForm;
 
-# $Id: ContactForm.pm,v 1.24 2003/04/11 13:14:23 Gunnar Hjalmarsson Exp $
+# $Id: ContactForm.pm,v 1.25 2003/07/01 22:38:15 Gunnar Hjalmarsson Exp $
 
 =head1 NAME
 
@@ -169,6 +169,10 @@ C<Flowed.pm> to those directories.
 
 =over 4
 
+=item v1.13 (Jul 1, 2003)
+
+Code cleanup.
+
 =item v1.12 (Apr 11, 2003)
 
 References to the form data for saving memory.
@@ -248,11 +252,11 @@ under the same terms as Perl itself.
 =cut
 
 use strict;
-use CGI qw(param escapeHTML);
+use CGI 'escapeHTML';
 my (%args, %in, %error);
 use vars qw($VERSION @ISA @EXPORT);
 
-$VERSION = '1.12';
+$VERSION = '1.13';
 
 use Exporter;
 @ISA = 'Exporter';
@@ -261,22 +265,21 @@ use Exporter;
 sub contactform {
     local $^W = 1;  # enables warnings
     %args = %in = %error = ();
-    arguments (@_);
-    if ($ENV{'REQUEST_METHOD'} eq 'POST') {
+    arguments(@_);
+    if ($ENV{REQUEST_METHOD} eq 'POST') {
         referercheck();
         formdata();
         if (formcheck() eq 'OK') {
             eval { mailsend() };
             if ($@) {
                 my $err = $@;
-                ($err = escapeHTML ($err)) =~ s/\n/<br>\n/g;
+                ($err = escapeHTML($err)) =~ s/\n/<br>\n/g;
                 print "<h1>Error</h1>\n<tt>", $err;
             }
             CFexit();
         }
     }
     formprint();
-    CFexit();
 }
 
 sub arguments {
@@ -315,18 +318,18 @@ sub arguments {
     for (keys %args) {
         push @error, "Unknown argument: '$_'\n" unless defined $defaults{$_};
     }
-    if ($args{'recmail'} and emailsyntax ($args{'recmail'}) eq 'ERR') {
-        push @error, "'$args{'recmail'}' is not a valid email address.\n";
+    if ($args{recmail} and emailsyntax($args{recmail}) eq 'ERR') {
+        push @error, "'$args{recmail}' is not a valid email address.\n";
     }
     for ('formtmplpath', 'resulttmplpath') {
         if ($args{$_} and !-f $args{$_}) {
             push @error, "Argument '$_': Can't find the file $args{$_}\n";
         }
     }
-    print "Content-type: text/html; charset=$args{'encoding'}\n\n";
+    print "Content-type: text/html; charset=$args{encoding}\n\n";
     if (@error) {
         print "<h1>Error</h1>\n<pre>";
-        for (@error) { print }
+        print for @error;
 
         print <<EXAMPLE;
 
@@ -344,24 +347,25 @@ EXAMPLE
 }
 
 sub referercheck {
-    return if $ENV{'HTTP_REFERER'} =~ /$ENV{'HTTP_HOST'}$ENV{'REQUEST_URI'}/i;
+    return if $ENV{HTTP_REFERER} =~ /$ENV{HTTP_HOST}$ENV{REQUEST_URI}/i;
     print "<h1>Error</h1>\n",
-          "<p>This script only permits data input from its self generated form.\n",
-          "<p><a href=\"$ENV{'REQUEST_URI'}\">Try again</a>";
+          "<p>This script prefers data input from its self generated form.\n",
+          "<p><a href=\"$ENV{REQUEST_URI}\">Try again</a>";
     CFexit();
 }
 
 sub formdata {
-    my $size = $ENV{'CONTENT_LENGTH'} ? $ENV{'CONTENT_LENGTH'} : (stat(STDIN))[7];
-    if ($size > 1024 * $args{'maxsize'}) {
+    my $size = $ENV{CONTENT_LENGTH} ? $ENV{CONTENT_LENGTH} : (stat(STDIN))[7];
+    if ($size > 1024 * $args{maxsize}) {
         print "<h1>Error</h1>\n",
-              "<p>The message size exceeds the $args{'maxsize'} KiB limit.\n",
+              "<p>The message size exceeds the $args{maxsize} KiB limit.\n",
               '<p><a href="javascript:history.back(1)">Back</a>';
         CFexit();
     }
 
     # create hash of references to the form data
-    for (param()) { $in{$_} = \param($_) }
+    my $o = new CGI;
+    $in{$_} = \$o->{$_}[0] for $o->param;
 
     # trim whitespace in message headers
     for (qw/name email subject/) {
@@ -373,13 +377,12 @@ sub formdata {
 
 sub formcheck {
     for (qw/name subject message/) { $error{$_} = ' class="error"' unless ${$in{$_}} }
-    $error{'email'} = ' class="error"' if emailsyntax (${$in{'email'}}) eq 'ERR';
+    $error{email} = ' class="error"' if emailsyntax(${$in{email}}) eq 'ERR';
     return %error ? '' : 'OK';
 }
 
 sub emailsyntax {
-    return 'ERR' unless (my $localpart = shift) =~ s/^(.+)@(.+)/$1/;
-    my $domain = $2;
+    return 'ERR' unless my ($localpart, $domain) = shift =~ /^(.+)@(.+)/;
     my $char = '[^()<>@,;:\/\s"\'&|.]';
     return 'ERR' unless $localpart =~ /^$char+(?:\.$char+)*$/ or $localpart =~ /^"[^",]+"$/;
     return $domain =~ /^$char+(?:\.$char+)+$/ ? '' : 'ERR';
@@ -388,50 +391,49 @@ sub emailsyntax {
 sub mailsend {
     # Extra headers
     my @extras = ();
-    push @extras, "X-Mailer: CGI::ContactForm $VERSION at $ENV{'HTTP_HOST'}";
-    push @extras, "X-Originating-IP: [$ENV{'REMOTE_ADDR'}]" if $ENV{'REMOTE_ADDR'};
+    push @extras, "X-Mailer: CGI::ContactForm $VERSION at $ENV{HTTP_HOST}";
+    push @extras, "X-Originating-IP: [$ENV{REMOTE_ADDR}]" if $ENV{REMOTE_ADDR};
 
     # Make message format=flowed (RFC 2646)
     require Text::Flowed;
     import Text::Flowed 'reformat';
-    ${$in{'message'}} = reformat (${$in{'message'}}, { max_length => 66, opt_length => 66 });
+    ${$in{message}} = reformat(${$in{message}}, { max_length => 66, opt_length => 66 });
     push @extras, 'MIME-Version: 1.0';
-    push @extras, "Content-type: text/plain; charset=$args{'encoding'}; format=flowed";
+    push @extras, "Content-type: text/plain; charset=$args{encoding}; format=flowed";
 
     # Send message
     require Mail::Sender;
     $Mail::Sender::NO_X_MAILER = 1;
     $Mail::Sender::SITE_HEADERS = join "\r\n", @extras;
     (new Mail::Sender) -> MailMsg ({
-        smtp      => $args{'smtp'},
-        from      => $args{'recmail'},
-        fake_from => namefix (${$in{'name'}}) . " <${$in{'email'}}>",
-        to        => namefix ($args{'recname'}) . " <$args{'recmail'}>",
-        bcc       => ${$in{'email'}},
-        subject   => ${$in{'subject'}},
-        msg       => ${$in{'message'}},
+        smtp      => $args{smtp},
+        from      => $args{recmail},
+        fake_from => namefix(${$in{name}}) . " <${$in{email}}>",
+        to        => namefix($args{recname}) . " <$args{recmail}>",
+        bcc       => ${$in{email}},
+        subject   => ${$in{subject}},
+        msg       => ${$in{message}},
     }) or die "Cannot send mail.\n$Mail::Sender::Error\n";
 
     # Print resulting page
-    my $sent_to = sprintf escapeHTML ($args{'sent_to'}), '<b>'
-      . escapeHTML ($args{'recname'}) . '</b>', '<b>' . escapeHTML (${$in{'email'}}) . '</b>';
+    my $sent_to = sprintf escapeHTML($args{sent_to}), '<b>'
+      . escapeHTML($args{recname}) . '</b>', '<b>' . escapeHTML(${$in{email}}) . '</b>';
     my @resultargs = qw/recname returnlinktext returnlinkurl title thanks/;
-    for (@resultargs) { $args{$_} = escapeHTML ($args{$_}) }
-    $args{'returnlinkurl'} =~ s/ /%20/g;
-    if ($args{'resulttmplpath'}) {
-        my $style = stylesheet();
+    $args{$_} = escapeHTML($args{$_}) for @resultargs;
+    $args{returnlinkurl} =~ s/ /%20/g;
+    if ($args{resulttmplpath}) {
         my %result_vars = ();
-        $result_vars{'style'} = \$style;
-        $result_vars{'sent_to'} = \$sent_to;
-        for (@resultargs) { $result_vars{$_} = \$args{$_} }
-        templateprint ($args{'resulttmplpath'}, %result_vars);
+        $result_vars{style} = \stylesheet();
+        $result_vars{sent_to} = \$sent_to;
+        $result_vars{$_} = \$args{$_} for @resultargs;
+        templateprint($args{resulttmplpath}, %result_vars);
     } else {
         headprint();
 
         print <<RESULT;
-<h1>$args{'thanks'}</h1>
+<h1>$args{thanks}</h1>
 <p>$sent_to</p>
-<p class="returnlink"><a href="$args{'returnlinkurl'}">$args{'returnlinktext'}</a></p>
+<p class="returnlink"><a href="$args{returnlinkurl}">$args{returnlinktext}</a></p>
 </body>
 </html>
 RESULT
@@ -439,36 +441,35 @@ RESULT
 }
 
 sub formprint {
-    (my $scriptname = $0 ? $0 : $ENV{'SCRIPT_FILENAME'}) =~ s/.*[\/\\]//;
+    (my $scriptname = $0 ? $0 : $ENV{SCRIPT_FILENAME}) =~ s/.*[\/\\]//;
     my $erroralert = %error ? '<p class="erroralert">'
-      . sprintf (escapeHTML ($args{'erroralert'}), '<span class="error">'
-      . "\n" . escapeHTML ($args{'marked'}) . '</span>') . '</p>' : '';
+      . sprintf (escapeHTML($args{erroralert}), '<span class="error">'
+      . "\n" . escapeHTML($args{marked}) . '</span>') . '</p>' : '';
     my @formargs = qw/recname returnlinktext returnlinkurl title namelabel
                       emaillabel subjectlabel msglabel reset send/;
-    for (@formargs) { $args{$_} = escapeHTML ($args{$_}) }
-    $args{'returnlinkurl'} =~ s/ /%20/g;
+    $args{$_} = escapeHTML($args{$_}) for @formargs;
+    $args{returnlinkurl} =~ s/ /%20/g;
     for (qw/name email subject message/) {
-        ${$in{$_}} = $in{$_} ? escapeHTML (${$in{$_}}) : '';
+        ${$in{$_}} = $in{$_} ? escapeHTML(${$in{$_}}) : '';
         $error{$_} = '' unless $error{$_};
     }
 
     # Prevent horizontal scrolling in NS4
-    my $softwrap = ($ENV{'HTTP_USER_AGENT'} =~ /Mozilla\/[34]/
-      and $ENV{'HTTP_USER_AGENT'} !~ /MSIE|Opera/) ? ' wrap="soft"' : '';
+    my $softwrap = ($ENV{HTTP_USER_AGENT} =~ /Mozilla\/[34]/
+      and $ENV{HTTP_USER_AGENT} !~ /MSIE|Opera/) ? ' wrap="soft"' : '';
 
-    if ($args{'formtmplpath'}) {
-        my $style = stylesheet();
+    if ($args{formtmplpath}) {
         my %form_vars = ();
-        $form_vars{'style'} = \$style;
-        $form_vars{'scriptname'} = \$scriptname;
-        $form_vars{'erroralert'} = \$erroralert;
-        for (@formargs) { $form_vars{$_} = \$args{$_} }
+        $form_vars{style} = \stylesheet();
+        $form_vars{scriptname} = \$scriptname;
+        $form_vars{erroralert} = \$erroralert;
+        $form_vars{$_} = \$args{$_} for @formargs;
         for (qw/name email subject message/) {
             $form_vars{$_} = $in{$_};
             $form_vars{$_.'error'} = \$error{$_};
         }
-        $form_vars{'softwrap'} = \$softwrap;
-        templateprint ($args{'formtmplpath'}, %form_vars);
+        $form_vars{softwrap} = \$softwrap;
+        templateprint($args{formtmplpath}, %form_vars);
     } else {
         headprint();
 
@@ -476,29 +477,29 @@ sub formprint {
 <form action="$scriptname" method="post">
 <table cellpadding="3">
 <tr>
-<td colspan="4"><h1 class="halign">$args{'title'} $args{'recname'}</h1></td>
+<td colspan="4"><h1 class="halign">$args{title} $args{recname}</h1></td>
 </tr><tr>
-<td><p$error{'name'}>$args{'namelabel'}</p></td><td><input type="text" name="name"
- value="${$in{'name'}}" size="20" />&nbsp;</td>
-<td><p$error{'email'}>$args{'emaillabel'}</p></td><td><input type="text" name="email"
- value="${$in{'email'}}" size="20" /></td>
+<td><p$error{name}>$args{namelabel}</p></td><td><input type="text" name="name"
+ value="${$in{name}}" size="20" />&nbsp;</td>
+<td><p$error{email}>$args{emaillabel}</p></td><td><input type="text" name="email"
+ value="${$in{email}}" size="20" /></td>
 </tr><tr>
-<td><p$error{'subject'}>$args{'subjectlabel'}</p></td>
-<td colspan="3"><input type="text" name="subject" value="${$in{'subject'}}" size="55" /></td>
+<td><p$error{subject}>$args{subjectlabel}</p></td>
+<td colspan="3"><input type="text" name="subject" value="${$in{subject}}" size="55" /></td>
 </tr><tr>
-<td colspan="4"><p$error{'message'}>$args{'msglabel'}</p></td>
+<td colspan="4"><p$error{message}>$args{msglabel}</p></td>
 </tr><tr>
 <td colspan="4">
-<textarea name="message" rows="8" cols="65"$softwrap>${$in{'message'}}</textarea>
+<textarea name="message" rows="8" cols="65"$softwrap>${$in{message}}</textarea>
 </td>
 </tr><tr>
 <td colspan="4" class="halign">
 $erroralert
-<input class="button" type="reset" value="$args{'reset'}" />&nbsp;&nbsp;
-<input class="button" type="submit" value="$args{'send'}" /></td>
+<input class="button" type="reset" value="$args{reset}" />&nbsp;&nbsp;
+<input class="button" type="submit" value="$args{send}" /></td>
 </tr><tr>
-<td colspan="4"><p class="returnlink"><a href="$args{'returnlinkurl'}">
-$args{'returnlinktext'}</a></p></td>
+<td colspan="4"><p class="returnlink"><a href="$args{returnlinkurl}">
+$args{returnlinktext}</a></p></td>
 </tr>
 </table>
 </form>
@@ -509,33 +510,31 @@ FORM
 }
 
 sub headprint {
-    my $style = stylesheet();
-
     print <<HEAD;
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN"
                       "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <head>
-<title>$args{'title'} $args{'recname'}</title>
+<title>$args{title} $args{recname}</title>
 <style type="text/css">
 .error { font-weight: bold }
 </style>
-$style
+${\stylesheet()}
 </head>
 <body>
 HEAD
 }
 
 sub stylesheet {
-    ($args{'styleurl'} = escapeHTML ($args{'styleurl'})) =~ s/ /%20/g;
-    return $args{'styleurl'} ? '<link rel="stylesheet" type="text/css" href="'
-      . "$args{'styleurl'}\" />" : '';
+    ($args{styleurl} = escapeHTML($args{styleurl})) =~ s/ /%20/g;
+    return $args{styleurl} ? '<link rel="stylesheet" type="text/css" href="'
+      . "$args{styleurl}\" />" : '';
 }
 
 sub templateprint {
     my ($template, %tmpl_vars) = @_;
     my @error = ();
-    open FH, $template or die "Can't open $template\n$!";
+    open FH, "< $template" or die "Can't open $template\n$!";
     my $output = join '', <FH>;
     close FH;
     $output =~ s[<(?:!--\s*)?tmpl_var\s*(?:name\s*=\s*)?
@@ -550,7 +549,7 @@ sub templateprint {
     ]egix;
     if (@error) {
         print "<h1>Error</h1>\n<pre>";
-        for (@error) { print }
+        print for @error;
         CFexit();
     }
     print $output;
